@@ -4,9 +4,10 @@ from os import environ
 
 from python_anticaptcha import AnticaptchaClient, NoCaptchaTaskProxylessTask
 
-api_key = environ['KEY']
+api_key = environ["KEY"]
 site_key_pattern = 'data-sitekey="(.+?)"'
-url = 'https://www.google.com/recaptcha/api2/demo?invisible=false'
+url = "https://www.google.com/recaptcha/api2/demo?invisible=false"
+EXPECTED_RESULT = "Verification Success... Hooray!"
 client = AnticaptchaClient(api_key)
 session = requests.Session()
 
@@ -17,16 +18,13 @@ def get_form_html():
 
 def get_token(form_html):
     site_key = re.search(site_key_pattern, form_html).group(1)
-    task = NoCaptchaTaskProxylessTask(
-        website_url=url,
-        website_key=site_key
-    )
+    task = NoCaptchaTaskProxylessTask(website_url=url, website_key=site_key)
     job = client.createTaskSmee(task)
     return job.get_solution_response()
 
 
 def form_submit(token):
-    return requests.post(url, data={'g-recaptcha-response': token}).text
+    return requests.post(url, data={"g-recaptcha-response": token}).text
 
 
 def process():
@@ -35,5 +33,5 @@ def process():
     return form_submit(token)
 
 
-if __name__ == '__main__':
-    assert 'Verification Success... Hooray!' in process()
+if __name__ == "__main__":
+    assert "Verification Success... Hooray!" in process()
